/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: CustomizationSpec.java 77 2011-06-30 07:58:07Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.api;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class CustomizationSpec {
    private String guestOsDomain;

    private String guestOsHostName;

    private List<String> guestOsDnsServerList = new ArrayList<String>();

    private List<VnicIPSettings> vnicIpSettingsList = new ArrayList<VnicIPSettings>();

    private Map<String, String> guestOsCustomizationParams;

    /**
     * Sets the DNS domain the guest OS belongs to
     * 
     * @param guestOsDomain DNS domain name
     */
    public void setGuestOsDomain(final String domain) {
        this.guestOsDomain = domain;
    }

    /**
     * Returns the guest OS DNS domain
     * 
     * @return
     */
    public String getGuestOsDomain() {
        return this.guestOsDomain;
    }

    /**
     * Returns the non-qualified hostname of the guest OS
     * 
     * @return
     */
    public String getGuestOsHostName() {
        return this.guestOsHostName;
    }

    /**
     * Sets the non-qualified hostname of the guest OS
     * 
     * @param guestOsHostName non-qualified hostname
     */
    public void setGuestOsHostName(final String hostName) {
        this.guestOsHostName = hostName;
    }

    /**
     * Returns the list of DNS servers to be used by the guest OS
     * 
     * @return list of DNS servers
     */
    public List<String> getGuestOsDnsServerList() {
        return new ArrayList<String>(this.guestOsDnsServerList);
    }

    /**
     * Sets the list of DNS servers to be used by the guest OS
     * 
     * @param guestOsDnsServerList list of DNS servers
     */
    public void setGuestOsDnsServerList(final List<String> dnsServerList) {
        this.guestOsDnsServerList = new ArrayList<String>(dnsServerList);
    }

    /**
     * Sets the VNIC IP settings of the VNIC(s) attached to this VM
     * 
     * @param ipSettingsList the list of VNIC IP settings
     */
    public void setVnicIpSettingsList(final List<VnicIPSettings> ipSettingsList) {
        this.vnicIpSettingsList = ipSettingsList;
    }

    /**
     * Returns the IP settings of each NIC attached to the VM
     * 
     * @return IP settings of each NIC attached to the VM
     */
    public List<VnicIPSettings> getVnicIpSettingsList() {
        return new ArrayList<VnicIPSettings>(this.vnicIpSettingsList);
    }

    /**
     * Returns the guest OS specific customization parameters
     * 
     * @return the customization parameters as a map of (key, value)
     */
    public Map<String, String> getGuestOsCustomizationParams() {
        return this.guestOsCustomizationParams;
    }

    /**
     * Sets guest-OS specific customization parameters
     * 
     * @param guestCustomization the list of customization parameters to set
     */
    public void setGuestOsCustomizationParams(final Map<String, String> guestCustomizationParams) {
        this.guestOsCustomizationParams = guestCustomizationParams;
    }

}
