/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: NotificationTypes.java 9 2011-06-14 14:44:07Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.api;

/**
 * Notification types that can be emitted by VMM MXBeans
 */
public interface NotificationTypes {
    /**
     * Emitted by a DomainMXBean when a new domain is created The user data of
     * the notification is the object name of the newly created domain
     */
    public static String DOMAIN_INVENTORY_ADD = "domain.add";

    /**
     * Emitted by a DomainMXBean when a server has been deleted The user data of
     * the notification is the object name of the deleted domain
     */
    public static String DOMAIN_INVENTORY_DEL = "domain.inventory.del";

    /**
     * Emitted when an error occurs during an addition of domain
     */
    public static String DOMAIN_ERROR = "domain.error";

    /**
     * Emitted by a DomainMXBean when a new server is created The user data of
     * the notification is the object name of the newly created server
     */
    public static String SERVER_POOL_INVENTORY_ADD = "serverpool.inventory.add";

    /**
     * Emitted by a DomainMXBean when a server has been deleted The user data of
     * the notification is the object name of the deleted server
     */
    public static String SERVER_POOL_INVENTORY_DEL = "serverpool.inventory.del";

    /**
     * Emitted by a ResourcePartitionMXBean when a sub-partition has been added.
     * The user data of the notification is the object name of the new partition
     */
    public static String RESOURCE_PARTITION_INVENTORY_ADD = "resourcepartition.inventory.add";

    /**
     * Emitted by a ResourcePartitionMXBean when a sub-partition has been
     * deleted. The user data of the notification is the object name of the
     * deleted partition
     */
    public static String RESOURCE_PARTITION_INVENTORY_DEL = "resourcepartition.inventory.del";

    /**
     * Emitted by a ResourcePartitionMXBean when its capacity has been changed.
     * The user data of the notification is the object name of the deleted
     * partition
     */
    public static String RESOURCE_PARTITION_INVENTORY_UPDATE = "resourcepartition.inventory.update";

    /**
     * Emitted when an error occurs during an addition of server
     */
    public static String SERVER_POOL_ERROR = "serverpool.error";

    /**
     * Emitted by a ServerPoolMXBean when a new host is created The user data of
     * the notification is the object name of the newly created host
     */
    public static String HOST_INVENTORY_ADD = "host.inventory.add";

    /**
     * Emitted by a ServerPoolMXBean when a host has been deleted The user data
     * of the notification is the object name of the deleted host
     */
    public static String HOST_INVENTORY_DEL = "host.inventory.del";

    /**
     * Emitted by a HostMXBean when the state of the host changes The
     * notification message has one of the following values:
     * <ul>
     * <li>RUNNING
     * <li>HALTED
     * <li>UNKNOWN
     * </ul>
     */
    public static String HOST_STATE_CHANGE = "host.state";

    /**
     * Emitted when an error occurs during an addition of host
     */
    public static String HOST_ERROR = "host.error";

    /**
     * Emitted by a HostMXBean when a new VM is created The user data of the
     * notification is the object name of the newly created virtual machine
     */
    public static String VM_ADD = "vm.add";

    /**
     * Emitted by a HostMXBean when a VM has been destroyed The user data of the
     * notification is the object name of the destroyed virtual machine.
     */
    public static String VM_DEL = "vm.del";

    /**
     * Emitted by a HostMXBean when a VM has been deleted The user data of the
     * notification is the object name of the deleted virtual machine.
     */
    public static String VM_INVENTORY_DEL = "vm.inventory.del";

    /**
     * Emitted by a VirtualMachineMXBean when the state of the VM changes The
     * notification message has one of the following values:
     * <ul>
     * <li>RUNNING
     * <li>HALTED
     * <li>SUSPENDED
     * <li>PAUSED
     * <li>UNKNOWN
     * </ul>
     */
    public static String VM_STATE_CHANGE = "vm.state";

    /**
     * Emitted by a a VirtualMachineMXBean after a successful migration The
     * notification message is set to the host name of the new host of the
     * virtual machine.
     */
    public static String VM_MIGRATION = "vm.migration";

    /**
     * Emitted by a a VirtualMachineMXBean when a migration is started The
     * notification message is set to the host name of the target host to where
     * the virtual machine is migrating
     */
    public static String VM_MIGRATION_START = "vm.migration.start";

    /**
     * Emitted by a a VirtualMachineMXBean when a migration has failed The
     * notification message is set to the host name of the target host of the
     * migration
     */
    public static String VM_MIGRATION_ABORT = "vm.migration.abort";

    /**
     * Emitted by a HostMXBean to report performance metrics
     */
    public static String PERF_REPORT = "host.perfreport";

    /**
     * Emitted by a HostMXBean when the state of the driver-specific connection
     * to the hypervisor changes
     */
    public static String HYPERVISOR_CONNECTION_STATE = "driver.connection.state";

    /**
     * Emitted when an error occurs during an asynchronous operation
     */
    public static String ERROR = "vm.error";

    /**
     * For debugging purposes only
     */
    public static String LOG = "log";
}
