/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: VNIC.java 9 2011-06-14 14:44:07Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.api;

import java.util.Map;

/**
 * Data object representing a virtual network interface card attached to a
 * virtual machine
 */
public class VNIC {
    private String macAddress;

    private String networkName;

    private String deviceName;

    private Map<String, String> properties;

    /**
     * Returns the properties of the virtual device
     * 
     * @return the properties of the virtual device
     */
    public Map<String, String> getProperties() {
        return this.properties;
    }

    public void setProperties(final Map<String, String> properties) {
        this.properties = properties;
    }

    /**
     * Returns the MAC address of the VNIC
     * 
     * @return the MAC address of the VNIC
     */
    public String getMacAddress() {
        return this.macAddress;
    }

    /**
     * Sets the MAC address of the VNIC
     * 
     * @param macAddress the MAC address of the VNIC
     */
    public void setMacAddress(final String macAddress) {
        this.macAddress = macAddress;
    }

    /**
     * Returns the name of the network this VNIC is connected with
     * 
     * @return the name of the network this VNIC is connected with
     */
    public String getNetworkName() {
        return this.networkName;
    }

    /**
     * Sets the name of the network this VNIC is connected with
     * 
     * @param networkName the name of the network this VNIC is connected with
     */
    public void setNetworkName(final String networkName) {
        this.networkName = networkName;
    }

    /**
     * Returns the device name of this VNIC as seen by the guest OS
     * 
     * @return the device name of this VNIC as seen by the guest OS
     */
    public String getDeviceName() {
        return this.deviceName;
    }

    /**
     * Sets the device name of this VNIC as seen by the guest OS
     * 
     * @param deviceName the device name of this VNIC as seen by the guest OS
     */
    public void setDeviceName(final String deviceName) {
        this.deviceName = deviceName;
    }

    @Override
    public String toString() {
        return "VNIC [deviceName=" + this.deviceName + ", macAddress=" + this.macAddress + ", networkName=" + this.networkName
            + "]";
    }

}
