/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: VNICSpec.java 9 2011-06-14 14:44:07Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.api;

import java.io.Serializable;
import java.util.Map;

/**
 * Helper class used to encapsulate configuration settings during a VNIC
 * creation
 */
public class VNICSpec implements Serializable {
    private static final long serialVersionUID = 8972942680400128219L;

    public static enum MacAddressAssignement {
        MANUAL, GENERATED
    }

    private MacAddressAssignement addressType;

    private String macAddress;

    private String networkName;

    private Map<String, String> properties;

    /**
     * Returns the properties of the virtual device
     * 
     * @return the properties of the virtual device
     */
    public Map<String, String> getProperties() {
        return this.properties;
    }

    /**
     * Sets the properties of the virtual device
     * 
     * @param properties the properties of the virtual device
     */
    public void setProperties(final Map<String, String> properties) {
        this.properties = properties;
    }

    /**
     * Returns the MAC address type. Valid values are "manual" and "generated"
     * 
     * @return the MAC address type
     */
    public MacAddressAssignement getAddressType() {
        return this.addressType;
    }

    /**
     * Sets the MAC address type. Valid values are "manual" and "generated"
     * 
     * @param addressType the MAC address type
     */
    public void setAddressType(final MacAddressAssignement addressType) {
        this.addressType = addressType;
    }

    /**
     * Returns the MAC address.
     * 
     * @return the MAC address or null if the addressType attribute is set to
     *         "generated"
     */
    public String getMacAddress() {
        return this.macAddress;
    }

    /**
     * Sets the MAC address of the VNIC. This parameter is taken into account
     * only if the addressType attribute is set to "manual"
     * 
     * @param macAddress the MAC address of the VNIC
     */
    public void setMacAddress(final String macAddress) {
        this.macAddress = macAddress;
    }

    /**
     * Returns the name of the network the VNIC must be connected with
     * 
     * @return the name of the network the VNIC must be connected with
     */
    public String getNetworkName() {
        return this.networkName;
    }

    /**
     * Sets the name of the network the VNIC must be connected with
     * 
     * @param networkName the name of the network the VNIC must be connected
     *        with
     */
    public void setNetworkName(final String networkName) {
        this.networkName = networkName;
    }

}
