/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: VirtualCdromSpec.java 9 2011-06-14 14:44:07Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.api;

import java.io.Serializable;
import java.util.Map;

/**
 * Helper class used to create a new virtual cdrom device
 */
public class VirtualCdromSpec implements Serializable {
    private static final long serialVersionUID = 3055563875778800387L;

    private Volume isoVolume;

    private Map<String, String> properties;

    /**
     * Returns the properties of the virtual device
     * 
     * @return the properties of the virtual device
     */
    public Map<String, String> getProperties() {
        return this.properties;
    }

    /**
     * Sets the properties of the virtual device
     * 
     * @param properties the properties of the virtual device
     */
    public void setProperties(final Map<String, String> properties) {
        this.properties = properties;
    }

    /**
     * Returns the ISO image associated with the cdrom device
     * 
     * @return the ISO image associated with the cdrom device
     */
    public Volume getIsoVolume() {
        return this.isoVolume;
    }

    /**
     * Sets the ISO image associated with the cdrom device
     * 
     * @param isoImage the ISO image associated with the cdrom device
     */
    public void setIsoVolume(final Volume isoVolume) {
        this.isoVolume = isoVolume;
    }

}
