/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: VirtualDiskSpec.java 589 2011-11-02 14:11:56Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.api;

import java.io.Serializable;
import java.util.Map;

/**
 * Helper class used to create a new virtual disk device
 */
public class VirtualDiskSpec implements Serializable {
    private static final long serialVersionUID = 5141777031203018087L;

    private DiskOperation diskOp;

    private long capacityMB;

    private Volume volume;

    private StoragePoolMXBean storagePool;

    private boolean copyOnWrite;

    private Map<String, String> properties;

    /**
     * Returns the properties of the virtual device
     * 
     * @return the properties of the virtual device
     */
    public Map<String, String> getProperties() {
        return this.properties;
    }

    /**
     * Sets the properties of the virtual device
     * 
     * @param properties the properties of the virtual device
     */
    public void setProperties(final Map<String, String> properties) {
        this.properties = properties;
    }

    /**
     * Returns the capacity of the virtual disk in megabytes
     * 
     * @return the capacity of the virtual disk in megabytes
     */
    public long getCapacityMB() {
        return this.capacityMB;
    }

    /**
     * Sets the capacity of the virtual disk in megabytes
     * 
     * @param capacityMB the capacity of the virtual disk in megabytes
     */
    public void setCapacityMB(final long capacityMB) {
        this.capacityMB = capacityMB;
    }

    /**
     * Returns the volume (if any) used to initialize the virtual disk
     * 
     * @return the volume (if any) used to initialize the virtual disk
     */
    public Volume getVolume() {
        return this.volume;
    }

    /**
     * Sets the volume (if any) used to initialize the virtual disk
     * 
     * @param volume the volume (if any) used to initialize the virtual disk
     */
    public void setVolume(final Volume volume) {
        this.volume = volume;
    }

    public DiskOperation getDiskOp() {
        return this.diskOp;
    }

    public void setDiskOp(final DiskOperation diskOp) {
        this.diskOp = diskOp;
    }

    public StoragePoolMXBean getStoragePool() {
        return this.storagePool;
    }

    public void setStoragePool(final StoragePoolMXBean storagePool) {
        this.storagePool = storagePool;
    }

    public boolean isCopyOnWrite() {
        return this.copyOnWrite;
    }

    public void setCopyOnWrite(final boolean copyOnWrite) {
        this.copyOnWrite = copyOnWrite;
    }
}
