/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: VnicIPSettings.java 9 2011-06-14 14:44:07Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.api;

/**
 * This class defines the IP settings of a virtual NIC attached to a VM
 */
public class VnicIPSettings {
    public enum IpAssignmentMode {
        FIXED, DHCP, NONE
    }

    private String ipAddress;

    private String subnetMask;

    private String gateway;

    private IpAssignmentMode ipAssignmentMode;

    /**
     * Constructs an instance of VnicIPSettings
     */
    public VnicIPSettings() {
    }

    /**
     * Constructs an instance initialized with the settings of another
     * VnicIPSettings instance
     * 
     * @param other the instance whose settings are copied into the new instance
     */
    public VnicIPSettings(final VnicIPSettings other) {
        if (other != null) {
            this.subnetMask = other.subnetMask;
            this.gateway = other.gateway;
            this.ipAddress = other.ipAddress;
            this.ipAssignmentMode = other.ipAssignmentMode;
        }
    }

    /**
     * Returns the subnet mask
     * 
     * @return the subnet mask
     */
    public String getSubnetMask() {
        return this.subnetMask;
    }

    /**
     * Sets the subnet mask
     * 
     * @param subnetMask the given subnet mask
     */
    public void setSubnetMask(final String subnetMask) {
        this.subnetMask = subnetMask;
    }

    /**
     * Returns the gateway
     * 
     * @return the gateway of the NIC associated with these settings
     */
    public String getGateway() {
        return this.gateway;
    }

    /**
     * Sets the gateway
     * 
     * @param gateway the given gateway
     */
    public void setGateway(final String gateway) {
        this.gateway = gateway;
    }

    /**
     * Returns the IP address
     * 
     * @return the IP address of the NIC associated with these settings
     */
    public String getIpAddress() {
        return this.ipAddress;
    }

    /**
     * Sets the IP address of the NIC associated with this instance
     * 
     * @param ipAddress the given IP address
     */
    public void setIpAddress(final String ipAddress) {
        this.ipAddress = ipAddress;
    }

    /**
     * Returns the IP assignement mode of the NIC associated with this instance
     * 
     * @return the IP assignment mode
     */
    public IpAssignmentMode getIpAssignmentMode() {
        return this.ipAssignmentMode;
    }

    /**
     * Sets the the IP assignment mode of the NIC associated with this instance
     * 
     * @param ipAssignmentMode the given IP assignment mode
     */
    public void setIpAssignmentMode(final IpAssignmentMode ipAssignmentMode) {
        this.ipAssignmentMode = ipAssignmentMode;
    }

    /*
     * (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        String s = "GuestIPSetting[";
        s += this.ipAssignmentMode + ":";
        if (this.ipAssignmentMode == IpAssignmentMode.FIXED) {
            s += "ip=" + this.ipAddress + ",mask=" + this.subnetMask + ",gateway=" + this.gateway;
        }
        s += "]";
        return s;
    }

}
