/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: Volume.java 434 2011-10-05 14:29:10Z chazalet $
 *
 */

package org.ow2.sirocco.vmm.api;

import java.io.Serializable;

/**
 * Data object representing a volume
 */
@SuppressWarnings("serial")
public class Volume implements Serializable {
    private String key;

    private long capacityMB;

    private long allocationMB;

    private String format;

    private String name;

    private String path;

    private String description;

    private String checkSum;

    private StoragePoolMXBean storagePool;

    /**
     * Returns the unique id of the volume
     * 
     * @return the unique id of the volume
     */
    public String getKey() {
        return this.key;
    }

    /**
     * Sets the unique id of the volume
     * 
     * @param uuid the unique id of the volume
     */
    public void setKey(final String key) {
        this.key = key;
    }

    /**
     * Returns the size of the volume in megabytes
     * 
     * @return the size of the volume in megabytes
     */
    public long getCapacityMB() {
        return this.capacityMB;
    }

    /**
     * Sets the size of the volume in megabytes
     * 
     * @param sizeMB the size of the volume in megabytes
     */
    public void setCapacityMB(final long capacityMB) {
        this.capacityMB = capacityMB;
    }

    /**
     * Returns the path of the file backing this volume
     * 
     * @return path of the file backing this volume
     */
    public String getPath() {
        return this.path;
    }

    /**
     * Sets the path of the file backing this volume
     * 
     * @param path path of the file backing this volume
     */
    public void setPath(final String path) {
        this.path = path;
    }

    public long getAllocationMB() {
        return this.allocationMB;
    }

    public void setAllocationMB(final long allocationMB) {
        this.allocationMB = allocationMB;
    }

    public String getFormat() {
        return this.format;
    }

    public void setFormat(final String format) {
        this.format = format;
    }

    public String getName() {
        return this.name;
    }

    public void setName(final String name) {
        this.name = name;
    }

    public String getDescription() {
        return this.description;
    }

    public void setDescription(final String description) {
        this.description = description;
    }

    public String getCheckSum() {
        return this.checkSum;
    }

    public void setCheckSum(final String checkSum) {
        this.checkSum = checkSum;
    }

    /**
     * Returns the storage pool this volume belongs to
     * 
     * @return the storage pool this volume belongs to
     */
    public StoragePoolMXBean getStoragePool() {
        return this.storagePool;
    }

    /**
     * Sets the storage pool this volume belong to
     * 
     * @param storagePool the storage pool this volume belongs to
     */
    public void setStoragePool(final StoragePoolMXBean storagePool) {
        this.storagePool = storagePool;
    }

    @Override
    public String toString() {
        return "Volume [key=" + this.key + ", capacityMB=" + this.capacityMB + ", allocationMB=" + this.allocationMB
            + ", format=" + this.format + ", name=" + this.name + ", path=" + this.path + ", description=" + this.description
            + ", checkSum=" + this.checkSum + ", storagePool=" + this.storagePool + "]";
    }

}
