/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: MonitorableMXBean.java 386 2011-10-03 12:17:20Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.api.monitoring;

import java.util.Date;

import org.ow2.sirocco.vmm.api.VMMException;

/**
 * Monitorable type
 */
public interface MonitorableMXBean {
    /**
     * Retrieve the list of metric infos
     * 
     * @return list of metrics or null if there are none
     * @throws VMMException
     */
    public PerfMetricInfo[] listPerfMetricInfos() throws VMMException;

    /**
     * Retrieve the current performance metric value for the given metric name
     * 
     * @param metricName name of the metric to retrieve
     * @return the current performance metric
     * @throws VMMException
     */
    public PerfMetric getPerfMetric(String metricName) throws VMMException;

    /**
     * Retrieve a table of performance metrics for a given time range
     * 
     * @param metricName name of the metric to retrieve
     * @param startTime start time of the time range
     * @param endTime end time of the time range
     * @param resolution the interval you want the values to have in
     *        milliseconds
     * @param conFun the consolidation function that is applied to the data you
     *        want to fetch
     * @return the metric time series
     * @throws VMMException
     */
    public PerfMetric[] getPerfMetrics(String metricName, Date startTime, Date endTime, long resolution,
        ConsolidationFunction conFun) throws VMMException;

    /**
     * Consolidation function
     */
    public enum ConsolidationFunction {
        AVERAGE, MAX, MIN, LAST;

        public String value() {
            return this.name();
        }

        public static ConsolidationFunction fromValue(final String v) {
            for (ConsolidationFunction cf : ConsolidationFunction.values()) {
                if (v.equals(cf.value())) {
                    return cf;
                }
            }
            return null;
        }
    }

}
