/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: PerfMetricInfo.java 386 2011-10-03 12:17:20Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.api.monitoring;

import java.util.Date;

/**
 * Performance metric info type
 */
public interface PerfMetricInfo {

    /**
     * Return the name of the metric
     */
    public String getName();

    /**
     * Return the unit of the metric
     */
    public Unit getUnit();

    /**
     * Return a description of the metric (or null if none)
     */
    public String getDescription();

    /**
     * Return the time of the oldest value available for this metric
     */
    public Date getStartTime();

    /**
     * Unit type
     */
    public enum Unit {
        /**
         * A quantity of items (for example the number of CPUs)
         */
        NUMBER,
        /**
         * Percentage
         */
        PERCENT,
        /**
         * The time in milliseconds
         */
        MILLISECOND,
        /**
         * The time in seconds
         */
        SECOND,
        /**
         * bytes per second
         */
        BYTES_PER_SEC,
        /**
         * Kilobytes per second
         */
        KILOBYTES_PER_SEC, OPERATIONS_PER_SEC, PACKETS_PER_SEC, ERRORS_PER_SEC,
        /**
         * Kilobits per second
         */
        KILOBITS_PER_SEC,
        /**
         * Kilobytes
         */
        KILOBYTES,
        /**
         * Megabytes
         */
        MEGABYTES;

        public String value() {
            return this.name();
        }

        public static Unit fromValue(final String v) {
            for (Unit u : Unit.values()) {
                if (v.equals(u.value())) {
                    return u;
                }
            }
            return null;
        }
    }
}
